#!/bin/bash
#*******************************************************************************
# E.S.O. - VLT project
#
# "@(#) $Id: fims.sh.tpl 209227 2011-02-01 17:17:46Z pbaksai $"
#
# who       when        what
# --------  ----------  --------------------------------------------------------
# pbaksai   2013/01/23  PPRS-23355: Corrections after testing.
#                       - Details.
#                       - Export HOST used by SkyCat_plugin.tcl
# pbaksai   2012/12/29  PPRS-23355: Corrections after testing.
#                       - More checks while looking for local SkyCat version.
# pbaksai   2012/12/28  PPRS-23355: Corrections after testing.
#                       - Construct PATH and LD_LIBRARY_PATH here
#                         for the case installer user is not the same as runtime
#                         user (case in wgsoffX machines).
#                       - Try to find out local SkyCat version
# pbaksai   2012/12/13  PPRS-23355: Eliminated Tcl/Tk and SkyCat code
# pbaksai   2012/11/28  PPRS-23355: Corrections after testing.
# pbaksai   2012/11/05  PPRS-23355: Corrections after testing.
# pbaksai   2012/11/04  PPRS-23355: Completed.
# pbaksai   2012/09/22  PPRS-23355: Created.
#
#*******************************************************************************
#   NAME
#       fims.sh - FIMS startup in user environment
#
#   SYNOPSIS
#       fims.sh [[-b|--batch] [-d|--debug] [-s|--screen <ip:d.s>] [-t|--trace] 
#                [-v|--verbose] [-h|--help] [-u|--usage] [<skycat opts>] --]
#               <camera>
#
#   DESCRIPTION
#       This script starts FIMS application in the user environment.
#
#   ARGUMENTS
#       <camera>       : [B|R] Character code of the FORS CCD
#                        No Default
#       <ip:d.s>       : IP address:display number.screen number
#                        Default $DISPLAY
#      ?<skycat opts>? : [skycat -?] Command line options passed to skycat
#                        Default -with_grid 1 -scrollbars 1 -rtd 0
#
#   PARAMETERS
#       -b|--batch     : Starts FIMS in batch mode. Available only to VLTSW ENG.
#       -d|--debug     : Enables debugging mode. Hidden from normal users.
#       -s|--screen    : Opens in specified screen.
#       -t|--trace     : Enables tracing mode. Hidden from normal users.
#       -v|--verbose   : Enables verbose mode. Hidden from normal users.
#       -h|--help|
#       -u|--usage     : Displays a help screen explaining the usage 
#
#   INPUTS
#
#   OUTPUTS
#
#   FILES
#
#   ENVIRONMENT
#       USER
#       HOST
#       HOME
#       DISPLAY
#       SHELL_DEBUG
#
#   RETURN VALUES
#       0: All OK
#       1: Cancelled due to insufficient conditions
#       2: Aborted due to errors
#
#   CAUTIONS
#       Uses GNU getopt which is incompatible with Mac OsX
#
#   EXAMPLES
#       fims.sh -file $HOME/FITS/ngc0815.fits -catalog $HOME/cat/gsc0815.ptl B
#       fims.sh -rtd 1 -with_grid 1 -scrollbars 1 -float_panel 1 -debug 1 R
#
#   SEE ALSO
#
#   BUGS
#
#-------------------------------------------------------------------------------
#        1         2         3         4         5         6         7         8
#23456789 123456789 123456789 123456789 123456789 123456789 123456789 1234567890
#
# Standard Initialization BEGIN
#
# Operating System flavors
#
if [ "`uname`" = "Linux" ]; then 
    enable -n echo
    bash=/bin/bash
    xterm=/usr/bin/xterm
    remote=/usr/bin/rsh
    ping=/bin/ping
    echo_option=-n
    count_option=-c
    count=1000
    rt_ini=""
elif [ "`uname`" = "HP-UX" ]; then 
    bash=/usr/bin/bash
    xterm=/usr/bin/X11/xterm
    remote=/usr/bin/remsh
    ping=/etc/ping
    echo_option=-n
    count_option=-n
    count=0
    rt_ini=""
elif [ "`uname`" = "Darwin" ]; then 
    bash=/bin/bash
    xterm=/usr/X11/bin/xterm
    remote=/usr/bin/rsh
    ping=/sbin/ping
    echo_option=-n
    count_option=-n
    count=0
    rt_ini=""
else 
    bash=bash
    remote=remsh
    xterm=xterm
    ping=ping
    echo_option=""
    count_option=-n
    count=0
    rt_ini=""
fi

#
# Name, date and time
#
progname=`echo $0 | awk '{i=split($1,a,"/"); if (i > 0) printf("%s",a[i]); else printf("%s",$1)}'`
progpath=`echo $0 | sed s/$progname//g`
datestamp=`date +'%Y-%m-%d'`
timestamp=`date +'%H:%M:%S'`

#
# Environment variables
#
user=${USER}
ws=${HOST:-`hostname`}
debug=${SHELL_DEBUG:-0}

#
# Constants
#
if [ "${debug}" = ""    -o \
     "${debug}" = "0"   -o \
     "${debug}" = "off" -o \
     "${debug}" = "OFF" -o \
     "${debug}" = "Off" -o \
     "${debug}" = "no"  -o \
     "${debug}" = "NO"  -o \
     "${debug}" = "No" ]; then
    debug=0
else
    debug=1
fi

# Standard Initialization END

# Local Initialization BEGIN
WORKING_DIR=`pwd`
# Local Initialization END

# Standard Library BEGIN
HelpAd() {
    echo " "
    echo "      To see the Help Screen use "
    echo "      $progname -h"
    echo " "
}

Help() {
    # Some options are kept hidden from users but available to developers:
    # batch, debug, trace, verbose, screen
    echo " "
    echo "      Usage: "
    echo "      $progname <camera> [<skycat opts>] [-h|--help] [-u|--usage] "
    echo "        where: "
    echo "           camera     : [B|R] Character code of the FORS CCD "
    echo "                           B: Configure FIMS for FORS Blue CCD "
    echo "                           R: Configure FIMS for FORS Red CCD "
    echo "           skycat opts: command line options passed to skycat "
    echo "                        (use 'skycat -?' to see all skycat options available) "
    echo "          -h or "
    echo "         --help       : displays this Help Screen "
    echo "          -u or "
    echo "         --usage      : displays long Help Screen "
    echo " "
}

Usage() {
    echo "      Usage: "
    echo "      $progname <camera> [<skycat opts>] [-h|--help] [-u|--usage] "
    echo "        where: "
    echo "           camera     : [B|R] Character code of the FORS CCD "
    echo "                           B: Configure FIMS for FORS Blue CCD "
    echo "                           R: Configure FIMS for FORS Red CCD "
    echo "           skycat opts: command line options passed to skycat "
    echo "           -cat <bool>              * Include ESO/Archive catalog extensions (default). "
    echo "           -catalog <name>          * Open a window for the given catalog on startup. "
    echo "           -colorramp_height <n>    * height of colorramp window (default: 12). "
    echo "           -float_panel <bool>      * put info panel in a popup window (default: 0). "
    echo "           -panel_layout <layout>   * panel layout, one of: 'saoimage', 'reverse', 'default'. "
    echo "           -panel_orient <orient>   * panel orientation, one of: 'horizontal', 'vertical' "
    echo "           -pickobjectorient <v>    * orientation for pick object win: 'horizontal', 'vertical'"
    echo "           -min_scale <n>           * minimum scale for magnification menu (default: -10). "
    echo "           -max_scale <n>           * maximum scale for magnification menu (default: 20). "
    echo "           -remote <bool>           * Use existing skycat process, if available, with Tk send. "
    echo "           -debug <bool>            * debug flag: run bg processes in fg. "
    echo "           -default_cmap <cmap>     * default colormap. "
    echo "           -default_itt <itt>       * default intensity transfer table. "
    echo "           -file <file>             * fits file to load ('-' for stdin). "
    echo "           -port <port>             * Listen for remote cmds on port (default: 0 = choose port). "
    echo "           -rtd <bool>              * Include ESO/VLT Real-Time Features. "
    echo "           -scrollbars <bool>       * Display scrollbars (not displayed by default). "
    echo "           -shm_data <bool>         * Put image data in sysV shared memory.  "
    echo "           -shm_header <bool>       * Put image header in sysV shared memory. "
    echo "           -usexshm <bool>          * Use X shared mem, if available (default). "
    echo "           -use_zoom_view <bool>    * Use a 'view' of the image for the zoom window (default). "
    echo "           -verbose <bool>          * Print diagnostic messages. "
    echo "           -with_colorramp <bool>   * Display the color bar (default). "
    echo "           -with_warp <bool>        * add bindings to move mouse ptr with arrow keys (default: 1). "
    echo "           -with_grid <bool>        * Include a WCS grid button (default: 0 = off). "
    echo "           -with_pan_window <bool>  * Display the pan window (default). "
    echo "           -with_zoom_window <bool> * Display the zoom window (default). "
    echo "           -zoom_factor <n>         * zooming factor (default: 4). "
    echo "          -h or "
    echo "         --help       : displays short Help Screen "
    echo "          -u or "
    echo "         --usage      : displays this Help Screen "
    echo " "
}

CleanUp() {
    echo "===> Cleaning up..."
    echo "     Done cleaning. <==="
    echo " "
}

PrintLine() {
    local m
    local l
    local f1
    local f2
    local s
    case $# in
        (0)
            m=""
            l=80
            f1="%s\n"
            f2="%s\n"
            s=""
            ;;
        (1)
            m="$1"
            l=80
            f1="%s\n"
            f2="%s\n"
            s=""
            ;;
        (2)
            m="$1"
            l=$2
            f1="%s\n"
            f2="%s\n"
            s=""
            ;;
        (3)
            m="$1"
            l=$2
            f1="$3"
            f2="$3"
            s=""
            ;;
        (4)
            m="$1"
            l=$2
            f1="$3"
            f2="$4"
            s=""
            ;;
        (5)
            m="$1"
            l=$2
            f1="$3"
            f2="$4"
            s="$5"
            ;;
        (*)
            m="$1"
            l=$2
            f1="$3"
            f2="$4"
            s="$5"
            ;;
    esac
    msg=`echo "$m" | \
         awk -v l=$l \
             -v f1="$f1" \
             -v f2="$f2" \
             -v s="$s" \
             -F '#' '{ \
                       f=f1; \
                       i = 1; \
                       while ( length(substr($1,i,l)) > 0 ) { \
                           printf(f,substr($1s,i,l)); \
                           f = f2; \
                           i = i + l; \
                       } \
                     }'`
    echo "$msg" 1>&2
}

Debug() {
    local l
    local f1
    local f2
    local s
    if [ $dflag -eq 1 ]; then
        l=51
        f1="     |##> DEBUG:   %-${l}s <##|\n"
        f2="     |##>          %-${l}s <##|\n"
        s=""
        PrintLine "$1" $l "$f1" "$f2" "$s"
    fi
}

Error() {
    local l
    local f1
    local f2
    local s
    l=51
    f1="     |*** ERROR:   %-${l}s ***|\n"
    f2="     |***          %-${l}s ***|\n"
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Warning() {
    local l
    local f1
    local f2
    local s
    l=51
    f1="     |*** WARNING: %-${l}s ***|\n"
    f2="     |***          %-${l}s ***|\n"
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Explain() {
    local l
    local f1
    local f2
    local s
    l=51
    f1="     |***          %-${l}s ***|\n"
    f2="     |***          %-${l}s ***|\n"
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Banner() {
    local l
    local f1
    local f2
    local s
    l=60
    f1="     |*** %-${l}s ***|\n"
    f2="     |*** %-${l}s ***|\n"
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Tell() {
    local l
    local f1
    local f2
    local s
    case $2 in
        0)
           l=75
           f1="     %-${l}s\n"
           f2="     %-${l}s\n"
           ;;
        1)
           l=70
           f1="          %-${l}s\n"
           f2="          %-${l}s\n"
           ;;
        2)
           l=65
           f1="               %-${l}s\n"
           f2="               %-${l}s\n"
           ;;
       (*)
           l=75
           f1="     %-${l}s\n"
           f2="     %-${l}s\n"
           ;;
    esac
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Doing() {
    local l
    local f1
    local f2
    local s
    case $2 in
        0)
           l=75
           f1="===> %-${l}s\n"
           f2="     %-${l}s\n"
           ;;
        1)
           l=70
           f1="     ---> %-${l}s\n"
           f2="          %-${l}s\n"
           ;;
        2)
           l=65
           f1="          +++> %-${l}s\n"
           f2="               %-${l}s\n"
           ;;
       (*)
           l=75
           f1="===> %-${l}s\n"
           f2="     %-${l}s\n"
           ;;
    esac
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Done() {
    local l
    local f1
    local f2
    local s
    case $2 in
        0)
           l=70
           f1="     Done %-${l}s\n"
           f2="          %-${l}s\n"
           s=" <==="
           ;;
        1)
           l=65
           f1="          Done %-${l}s\n"
           f2="               %-${l}s\n"
           s=" <---"
           ;;
        2)
           l=60
           f1="               Done %-${l}s\n"
           f2="                    %-${l}s\n"
           s=" <+++"
           ;;
       (*)
           l=70
           f1="     Done %-${l}s\n"
           f2="          %-${l}s\n"
           s=" <==="
           ;;
    esac
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Frame() {
    frm="+--------------------------------------------------------------------+"
    msg=`echo $frm | awk -F '#' '{printf("     %-70s\n",$1)}'`
    echo "$msg" 1>&2
}

Exit() {
    CleanUp
    case $1 in
        0)
            Frame
            Banner "END    $progname"
            Frame
            ;;
        1)
            Frame
            Banner "CANCEL $progname"
            Frame
            ;;
        2)
            Frame
            Banner "ABORT  $progname"
            Frame
            ;;
        (*)
            Frame
            Banner "EXIT $1 $progname"
            Frame
            ;;
    esac
    exit $1
}
# Standard Library END

# Local Library BEGIN
Period() {
    # Year with century
    year=`date +'%Y'`
    # Month without leading zeroes
    month=`date +'%m' | awk '{printf("%d",$1)}'`
    period=$((((${year}-1968)*12+${month}+2)/6))
    return $period
}
# Local Library END

################
# MAIN PROGRAM #
################

# Standard Prologue BEGIN
echo ""
Frame
Banner "BEGIN  $progname"
Frame

# Check parameters

bflag=0
dflag=0
eflag=0
sflag=0
tflag=0
vflag=0
display=$DISPLAY
CAMERA=U
SCOPTS=""

# Options may be followed by one colon to indicate they have a required argument,
# or by two colons to indicate they have an optional argument.
# All SkyCat options are included and they all require an argument.
options=`getopt -q -o bdhs:tuv -a --long batch,debug,help,screen:,trace,usage,verbose \
                                  --long cat:,catalog:,colorramp:,float_panel: \
                                  --long panel_layout:,panel_orient:,pickobjectorient: \
                                  --long min_scale:,max_scale:,remote: \
                                  --long default_cmap:,default_itt:,file:,port: \
                                  --long rtd:,scrollbars:,shm_data:,shm_header: \
                                  --long usexshm:,use_zoom_view:,verbose: \
                                  --long with_colorramp:,with_warp:,with_grid: \
                                  --long with_pan_window:,with_zoom_window:,zoom_factor: \
                                  -n $progname -- "$@"`

# Catches invalid options
if [ $? != 0 ]; then
    Warning "unrecognized option(s) ignored"
fi

# Processes valid options
eval set -- "$options"
while [ $# -gt 0 ]; do
    case $1 in
        -b | --batch)
            bflag=1
            Banner "Batch ON."
            Frame
            ;;
        -d | --debug)
            dflag=1
            # Pass it down to SkyCat
            SCOPTS="$SCOPTS -debug 1"
            Debug "Turned ON."
            Frame
            ;;
        -h | --help)
            Help
            Exit 0
            ;;
        -s | --screen)
            sflag=1
            display=$2
            Banner "FIMS opens in $display screen"
            Frame
            shift
            ;;
        -t | --trace)
            tflag=1
            Banner "Trace ON."
            Frame
            ;;
        -u | --usage)
            Usage
            Exit 0
            ;;
        -v | --verbose)
            vflag=1
            Banner "Verbose ON."
            ;;
        --cat | \
        --catalog | \
        --colorramp | \
        --float_panel | \
        --panel_layout | \
        --panel_orient | \
        --pickobjectorient | \
        --min_scale | \
        --max_scale | \
        --remote | \
        --default_cmap | \
        --default_itt | \
        --file | \
        --port | \
        --rtd | \
        --scrollbars | \
        --shm_data | \
        --shm_header | \
        --usexshm | \
        --use_zoom_view | \
        --verbose | \
        --with_colorramp | \
        --with_warp | \
        --with_grid | \
        --with_pan_window | \
        --with_zoom_window | \
        --zoom_factor)
            # SkyCat passthrough:
            # Cumulate options and their arguments
            SCOPTS="$SCOPTS $1 $2"
            shift
            ;;
        (--)
            shift
            break
            ;;
        (--*)
            # Catches long options that are allowed by getopt but not considered
            # in this case statement.
            Error "invalid long option $1"
            eflag=1
            ;;
        (-?)
            # Catches short options that are allowed by getopt but not considered
            # in this case statement.
            Error "invalid short option $1"
            eflag=1
            ;;
        (*)
            # Catches non-option arguments, to be processed later
            # (for the case when no -- was used to end option's section)
            break
            ;;
    esac
    shift
done

# Processes valid non-option arguments
shift $((OPTIND-1))
case $# in
    (0)
        Help
        Exit 0
        ;;
    (*)
        CAMERA=$1
        shift
        ;;
esac

# Catches remaining non-option arguments
while [ $# -gt 0 ]; do
    case $1 in
        (*)
            Warning "invalid argument $1 ignored"
            ;;
    esac
    shift
done

if [ $eflag -ne 0 ]; then
    HelpAd
    Exit $eflag
fi
dflag=$(( dflag || debug ))
# Standard Prologue END

# Main Algorithm BEGIN
if [ $dflag -eq 1 ]; then
    export FIMS_DEBUG=ON
fi
if [ $sflag -eq 1 ]; then
    export DISPLAY=$display
fi
if [ $tflag -eq 1 ]; then
    export FIMS_TRACE=ON
fi
if [ $vflag -eq 1 ]; then
    export FIMS_VERBOSE=ON
fi
# Default options for SkyCat
if [ -z "$SCOPTS" ]; then
    SCOPTS="-with_grid 1 -scrollbars 1 -rtd 0"
fi
# Strip quotes from string coming from shell
# and replace double hyphens with -
SCOPTS=`echo $SCOPTS | sed -e s/\"//g -e s/--/-/g`

case $CAMERA in
    B)
        Tell "Configuring FIMS for FORS Blue..."
        ;;
    R)
        Tell "Configuring FIMS for FORS Red..."
        ;;
    *)
        Error "Invalid camera $CAMERA."
        Explain "Camera should be B (Blue) or R (Red)."
        Exit 1
esac

# Receive installation paths from installer script
FIMS_BASE_PATH=@@FIMSBASEPATH@@
BINPATH=@@BINPATH@@
LIBPATH=@@LIBPATH@@
BIN_PATH=`echo ${BINPATH} | sed s/[/]/\\\\\\\\\\\\\\\\\\\\\\\\\\\//g`
LIB_PATH=`echo ${LIBPATH} | sed s/[/]/\\\\\\\\\\\\\\\\\\\\\\\\\\\//g`

# Extract binpath if present, then add it again. This way, if it is not present
# then it gets added, else it is not copied. Same for libpath.
CMD="echo $PATH | `echo $BIN_PATH: | awk '{printf(\"sed -e s/%s//g\",$1)}'`"
Debug "CMD BIN = >$CMD<"
SUBPATH=`eval $CMD`
Debug "SUBPATH BIN = >$SUBPATH<"
export PATH=$BINPATH:$SUBPATH

CMD="echo $LD_LIBRARY_PATH | `echo $LIB_PATH: | awk '{printf(\"sed -e s/%s//g\",$1)}'`"
Debug "CMD LIB = >$CMD<"
SUBPATH=`eval $CMD`
Debug "SUBPATH LIB = >$SUBPATH<"
export LD_LIBRARY_PATH=$LIBPATH:$SUBPATH

export HOST=$ws
export FORS_CAM=$CAMERA
export VLTROOT=@@VLTPATH@@
export INSROOT=@@INSPATH@@
export INSUSER=@@USER@@
export FIMSROOT=$FIMS_BASE_PATH
export ISF_DIR=$FIMSROOT/config
export PREP_DIR=$HOME/$INSUSER/PREP
export LOG_DIR=$HOME/$INSUSER/LOG
export SET_DIR=$HOME/$INSUSER/SET
ESO_PLUGIN=${FIMS_BASE_PATH}/lib/libesoPlugins.tcl/GraphFeatures_plugin.tcl
FC_PLUGIN=${FIMS_BASE_PATH}/lib/libfcPlugins.tcl/FindingChart_plugin.tcl
FIMS_PLUGIN=${FIMS_BASE_PATH}/lib/libfimsPlugins.tcl/SkyCat_plugin.tcl
export SKYCAT_PLUGIN=$FC_PLUGIN:$ESO_PLUGIN:$FIMS_PLUGIN
export SKYSEARCH_PLUGIN=${FIMS_BASE_PATH}/lib/libfimsPlugins.tcl/SkySearch_plugin.tcl
# export SKYCAT_CONFIG=file:${FIMS_BASE_PATH}/config/skycat.cfg
export SKYCAT_CONFIG=file:${HOME}/${INSUSER}/skycat.cfg
export SKYCAT_LOGO=${FIMS_BASE_PATH}/bitmap/skycat-logo.gif
export TCS_ENVNAME=wt0tcs
unset MODROOT

Debug "HOST             = >$HOST<"
Debug "FIMS_BASE_PATH   = >$FIMS_BASE_PATH<"
Debug "ESO_PLUGIN       = >$ESO_PLUGIN<"
Debug "FC_PLUGIN        = >$FC_PLUGIN<"
Debug "FIMS_PLUGIN      = >$FIMS_PLUGIN<"
Debug "SKYSEARCH_PLUGIN = >$SKYS_PLUGIN<"
Debug "SKYCAT_CONFIG    = >$SKYCAT_CONFIG<"
Debug "SKYCAT_LOGO      = >$SKYCAT_LOGO<"
Debug "VLTROOT          = >$VLTROOT<"
Debug "TCLROOT          = >$TCLTK_ROOT<"
Debug "INSROOT          = >$INSROOT<"
Debug "INSUSER          = >$INSUSER<"
Debug "PREP_DIR         = >$PREP_DIR<"
Debug "LOG_DIR          = >$LOG_DIR<"
Debug "SET_DIR          = >$SET_DIR<"
Debug "PATH             = >$PATH<"
Debug "LD_LIBRARY_PATH  = >$LD_LIBRARY_PATH<"

# Verification of environment
if [ $bflag -eq 1 -a ! -f $FIMS_BASE_PATH/bin/fims_ec ]; then
    Error "Batch mode not available"
    eflag=2
fi
if [ $eflag -ne 0 ]; then
    Exit $eflag
fi

# Find out component versions
if [ -a $FIMSROOT/doc/fims_svn.txt ]; then
    SVN_INFO=`cat $FIMSROOT/doc/fims_svn.txt`
else
    SVN_INFO="Path: unknown URL: unknown Repository Root: unknown Repository UUID: 00000000-0000-0000-0000-000000000000 Revision: 000000 Node Kind: directory Schedule: normal Last Changed Author: unknown Last Changed Rev: 000000 Last Changed Date: 0000-00-00 00:00:00 +0000 (Dow, 00 Mon 0000)"
fi
# Exports the SkyCat version required by FIMS, in case the one in this
# package gets replaced.
if [ -a $FIMSROOT/doc/skycat_version.txt ]; then
    SKYCAT_VER=`cat $FIMSROOT/doc/skycat_version.txt`
else
    # Try to find installed SkyCat version
    libs=`echo $LD_LIBRARY_PATH | sed s/:/' '/g`
    files=""
    for l in $libs ; do
        if [ -d $l ]; then
            files="$files `find $l -name skycatConfig.sh`"
        fi
    done
    for f in $files ; do
        v=`grep skycat_VERSION $f`
    done
    SKYCAT_VER=`echo $v | sed s/skycat_VERSION=//g | sed s/[\']//g`
fi
if [ -z $SKYCAT_VER ]; then
    Warning "SkyCat installation could not be found in this system."
    SKYCAT_VER=0.0.0
fi
export SKYCAT_VER

if [ -z "$MOD_VERSION" ]; then
    MOD_DATE=`echo $SVN_INFO | awk '/Last Changed Date:/{printf("%s", $29)}'`
    MOD_TIME=`echo $SVN_INFO | awk '/Last Changed Date:/{printf("%s", $30)}'`
    MOD_VERSION=`echo $SVN_INFO | awk '/Last Changed Rev:/{printf("%s", $25)}'`
    export MOD_VERSION
fi
M_V=$MOD_VERSION
S_V=$SKYCAT_VER


echo ""
echo ""
echo ""
echo "  W E L C O M E     T O     F I M S"
echo " -----------------------------------"
echo
echo " +----------------+                +---------------------+"
echo "" | awk -v MV=$M_V -v SV=$S_V '{ printf(" | FIMS  %8s |----plugin----> | SkyCatTool %8s |\n", MV, SV) }'
echo " +----------------+                +---------------------+"
echo
echo " +------------------------------------------+"
echo "" | awk -v MD=$MOD_DATE -v MT=$MOD_TIME '{ printf(" | last checkin : %s GD %s UT", MD, MT) }'
echo " | INPUT : "$PREP_DIR
echo " | now is       : "`date -u +%Y-%m-%d`" GD "`date -u +%H:%M:%S`" UT | OUTPUT: "$SET_DIR
echo " | FIMS requires: SkyCat "$S_V"              | LOGS  :" $LOG_DIR
echo " +------------------------------------------+"
echo ""
echo ""
echo "skycat ${SCOPTS}..."
if [ $bflag -eq 1 ]; then
    fims_ec $SCOPTS
else
    skycat $SCOPTS
fi
# Main Algorithm END

# Standard Epilogue BEGIN
Exit 0
# Standard Epilogue END

#
#___FIMS___
