#!/bin/bash
#*******************************************************************************
# E.S.O. - VLT project
#
# "@(#) $Id: fims_install.sh 237728 2013-01-25 21:11:08Z pbaksai $"
#
# who       when        what
# --------  ----------  --------------------------------------------------------
# pbaksai   2013/01/23  PPRS-23355: Install pre-compiled SkyCat and Tcl/Tk with
#                       option -r (required)
# pbaksai   2012/12/28  PPRS-23355: Construction of PATH and LD_LIBRARY_PATH
#                       moved to fims.sh.tpl for the case installer user is not
#                       the same as runtime user (case in wgsoffX machines).
# pbaksai   2012/12/13  PPRS-23355: Eliminated Tcl/Tk and SkyCat code
# pbaksai   2012/11/28  PPRS-23355: Corrections after testing.
# pbaksai   2012/11/05  PPRS-23355: Corrections after testing.
# pbaksai   2012/11/04  PPRS-23355: Completed.
# pbaksai   2012/09/22  PPRS-23355: Created.
#
#*******************************************************************************
#   NAME
#       fims_install.sh - Package installation script for fimsLINUXRH9
#
#   SYNOPSIS
#       fims_install.sh [[-c|--compile]
#                        [-d|--debug]
#                        [-h|--help]
#                        [-r|--required]
#                        [-u|--uninstall] --]
#                       [<path>]
#
#
#   DESCRIPTION
#       This script installs FIMS package distribution in user's environment.
#
#   ARGUMENTS
#       ?<path>?       : Path to the installation directory
#                        Default current directory
#
#   PARAMETERS
#       -c|--compile   : Recompiles all package components in user's environment.
#       -d|--debug     : Enables debugging mode.
#       -h|--help      : Displays a help screen explaining the usage 
#       -r|--required  : Installs pre-compiled required packages: Tcl/Tk, SkyCat
#       -u|--uninstall : Removes FIMS package
#
#   INPUTS
#
#   OUTPUTS
#       <uninstaller>  : Script generated for uninstalling the package
#                        ./fimsLINUXRH9.uninstall
#
#   FILES
#       ./fimsLINUXRH9.tar.gz    FIMS package
#       ./fimsLINUXRH9.uninstall Macro for -u option
#
#   ENVIRONMENT
#       USER
#       HOST
#       HOME
#       SHELL_DEBUG
#       VLTROOT
#       INTROOT
#
#   RETURN VALUES
#       0: All OK
#       1: Cancelled due to insufficient conditions
#       2: Aborted due to errors
#
#   CAUTIONS
#       Uses GNU getopt which is incompatible with Mac OsX
#
#   EXAMPLES
#
#   SEE ALSO
#
#   BUGS
#
#-------------------------------------------------------------------------------
#        1         2         3         4         5         6         7         8
#23456789 123456789 123456789 123456789 123456789 123456789 123456789 1234567890
#
# Standard Initialization BEGIN
#
# Operating System flavors
#
if [ "`uname`" = "Linux" ]; then 
    enable -n echo
    bash=/bin/bash
    xterm=/usr/bin/xterm
    remote=/usr/bin/rsh
    ping=/bin/ping
    echo_option=-n
    count_option=-c
    count=1000
    rt_ini=""
elif [ "`uname`" = "HP-UX" ]; then 
    bash=/usr/bin/bash
    xterm=/usr/bin/X11/xterm
    remote=/usr/bin/remsh
    ping=/etc/ping
    echo_option=-n
    count_option=-n
    count=0
    rt_ini=""
elif [ "`uname`" = "Darwin" ]; then 
    bash=/bin/bash
    xterm=/usr/X11/bin/xterm
    remote=/usr/bin/rsh
    ping=/sbin/ping
    echo_option=-n
    count_option=-n
    count=0
    rt_ini=""
else 
    bash=bash
    remote=remsh
    xterm=xterm
    ping=ping
    echo_option=""
    count_option=-n
    count=0
    rt_ini=""
fi

#
# Name, date and time
#
progname=`echo $0 | awk '{i=split($1,a,"/"); if (i > 0) printf("%s",a[i]); else printf("%s",$1)}'`
progpath=`echo $0 | sed s/$progname//g`
datestamp=`date +'%Y-%m-%d'`
timestamp=`date +'%H:%M:%S'`

#
# Environment variables
#
user=${USER}
ws=${HOST:-`hostname`}
debug=${SHELL_DEBUG:-0}

#
# Constants
#
if [ "${debug}" = ""    -o \
     "${debug}" = "0"   -o \
     "${debug}" = "off" -o \
     "${debug}" = "OFF" -o \
     "${debug}" = "Off" -o \
     "${debug}" = "no"  -o \
     "${debug}" = "NO"  -o \
     "${debug}" = "No" ]; then
    debug=0
else
    debug=1
fi

# Standard Initialization END

# Local Initialization BEGIN
PERIOD=91
INSTRUMENT=FORS2
UNPACK_DIR=`pwd`
PACK_NAME=fimsLINUXRH9
INSROOT=$HOME
INSUSER=.fims
PREP_DIR=$INSROOT/$INSUSER/PREP
LOG_DIR=$INSROOT/$INSUSER/LOG
SET_DIR=$INSROOT/$INSUSER/SET

# Local Initialization END

# Standard Library BEGIN
HelpAd() {
    echo " "
    echo "      To see the Help Screen use "
    echo "      $progname -h"
    echo " "
}

Help() {
    echo " "
    echo "      Usage: "
    echo "      $progname [<path>] [-c|--compile] [-d|--debug] [-h|--help] [-r|--required] [-u|--uninstall] "
    echo "        where: "
    echo "           path:      path to the installation directory "
    echo "                      Default is current directory "
    echo "          -c or "
    echo "         --compile:   recompiles FIMS executables "
    echo "          -d or "
    echo "         --debug:     enables debugging mode "
    echo "          -h or "
    echo "         --help:      displays this Help Screen "
    echo "          -r or "
    echo "         --required:  installs pre-compiled packages: Tcl/Tk, SkyCat "
    echo "          -u or "
    echo "         --uninstall: removes FIMS package "
    echo " "
}

CleanUp() {
    echo "===> Cleaning up..."
    echo "     Done cleaning. <==="
    echo " "
}

PrintLine() {
    local m
    local l
    local f1
    local f2
    local s
    case $# in
        (0)
            m=""
            l=80
            f1="%s\n"
            f2="%s\n"
            s=""
            ;;
        (1)
            m="$1"
            l=80
            f1="%s\n"
            f2="%s\n"
            s=""
            ;;
        (2)
            m="$1"
            l=$2
            f1="%s\n"
            f2="%s\n"
            s=""
            ;;
        (3)
            m="$1"
            l=$2
            f1="$3"
            f2="$3"
            s=""
            ;;
        (4)
            m="$1"
            l=$2
            f1="$3"
            f2="$4"
            s=""
            ;;
        (5)
            m="$1"
            l=$2
            f1="$3"
            f2="$4"
            s="$5"
            ;;
        (*)
            m="$1"
            l=$2
            f1="$3"
            f2="$4"
            s="$5"
            ;;
    esac
    msg=`echo "$m" | \
         awk -v l=$l \
             -v f1="$f1" \
             -v f2="$f2" \
             -v s="$s" \
             -F '#' '{ \
                       f=f1; \
                       i = 1; \
                       while ( length(substr($1,i,l)) > 0 ) { \
                           printf(f,substr($1s,i,l)); \
                           f = f2; \
                           i = i + l; \
                       } \
                     }'`
    echo "$msg" 1>&2
}

Debug() {
    local l
    local f1
    local f2
    local s
    if [ $dflag -eq 1 ]; then
        l=51
        f1="     |##> DEBUG:   %-${l}s <##|\n"
        f2="     |##>          %-${l}s <##|\n"
        s=""
        PrintLine "$1" $l "$f1" "$f2" "$s"
    fi
}

Error() {
    local l
    local f1
    local f2
    local s
    l=51
    f1="     |*** ERROR:   %-${l}s ***|\n"
    f2="     |***          %-${l}s ***|\n"
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Warning() {
    local l
    local f1
    local f2
    local s
    l=51
    f1="     |*** WARNING: %-${l}s ***|\n"
    f2="     |***          %-${l}s ***|\n"
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Explain() {
    local l
    local f1
    local f2
    local s
    l=51
    f1="     |***          %-${l}s ***|\n"
    f2="     |***          %-${l}s ***|\n"
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Banner() {
    local l
    local f1
    local f2
    local s
    l=60
    f1="     |*** %-${l}s ***|\n"
    f2="     |*** %-${l}s ***|\n"
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Tell() {
    local l
    local f1
    local f2
    local s
    case $2 in
        0)
           l=75
           f1="     %-${l}s\n"
           f2="     %-${l}s\n"
           ;;
        1)
           l=70
           f1="          %-${l}s\n"
           f2="          %-${l}s\n"
           ;;
        2)
           l=65
           f1="               %-${l}s\n"
           f2="               %-${l}s\n"
           ;;
       (*)
           l=75
           f1="     %-${l}s\n"
           f2="     %-${l}s\n"
           ;;
    esac
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Doing() {
    local l
    local f1
    local f2
    local s
    case $2 in
        0)
           l=75
           f1="===> %-${l}s\n"
           f2="     %-${l}s\n"
           ;;
        1)
           l=70
           f1="     ---> %-${l}s\n"
           f2="          %-${l}s\n"
           ;;
        2)
           l=65
           f1="          +++> %-${l}s\n"
           f2="               %-${l}s\n"
           ;;
       (*)
           l=75
           f1="===> %-${l}s\n"
           f2="     %-${l}s\n"
           ;;
    esac
    s=""
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Done() {
    local l
    local f1
    local f2
    local s
    case $2 in
        0)
           l=70
           f1="     Done %-${l}s\n"
           f2="          %-${l}s\n"
           s=" <==="
           ;;
        1)
           l=65
           f1="          Done %-${l}s\n"
           f2="               %-${l}s\n"
           s=" <---"
           ;;
        2)
           l=60
           f1="               Done %-${l}s\n"
           f2="                    %-${l}s\n"
           s=" <+++"
           ;;
       (*)
           l=70
           f1="     Done %-${l}s\n"
           f2="          %-${l}s\n"
           s=" <==="
           ;;
    esac
    PrintLine "$1" $l "$f1" "$f2" "$s"
}

Frame() {
    frm="+--------------------------------------------------------------------+"
    msg=`echo $frm | awk -F '#' '{printf("     %-70s\n",$1)}'`
    echo "$msg" 1>&2
}

Exit() {
    CleanUp
    case $1 in
        0)
           Frame
           Banner "END    $progname"
           Frame
           ;;
        1)
           Frame
           Banner "CANCEL $progname"
           Frame
           ;;
        2)
           Frame
           Banner "ABORT  $progname"
           Frame
           ;;
       (*)
           Frame
           Banner "EXIT $1 $progname"
           Frame
           ;;
    esac
    exit $1
}
# Standard Library END

# Local Library BEGIN
Period() {
    # Year with century
    year=`date +'%Y'`
    # Month without leading zeroes
    month=`date +'%m' | awk '{printf("%d",$1)}'`
    period=$((((${year}-1968)*12+${month}+2)/6))
    return $period
}

SafeLink() {
    source=$1
    dest=$2
    Debug "Source     : >$source<"
    Debug "Destination: >$dest<"
    if [ "$source" = "" -o "$dest" = "" ]; then
        Warning "could not link, source and/or destination are/is blank"
        Explain "Source     : >$source<"
        Explain "Destination: >$dest<"
        return 1
    fi
    # Remove existing destination link to package item
    # so that it does not get backed up again.
    if [ -h $dest ]; then
        if [ "`ls -laAB $dest 2>&- | grep $PACK_NAME`" != "" ]; then
            rm -f $dest 2>&-
        fi
    fi
    # Link making a backup of destination if exists
    Debug "ln --suffix=.fims -b -f -s $source $dest"
    ln --suffix=.fims -b -f -s $source $dest 2>&-
    if [ $? -ne 0 ]; then
        Warning "Error: ln --suffix=.fims -b -f -s $source $dest failed"
        Explain "Symbolic link from $source to $dest was not established."
    fi
    # Register in uninstaller macro
    if [ -f $upath ]; then
        # Remove link installed by package
        Debug "echo rm -f $dest 2>&- >> $upath"
        echo "rm -f $dest 2>&-" >> $upath
        # Restore backup made by ln -b above
        Debug "echo mv -f ${dest}.fims $dest 2>&- >> $upath"
        echo "mv -f ${dest}.fims $dest 2>&-" >> $upath
    fi
    
    return 0
}
# Local Library END

################
# MAIN PROGRAM #
################

# Standard Prologue BEGIN
Period
Frame
Banner "BEGIN  $progname"
Frame

# Check parameters

cflag=0
dflag=0
eflag=0
rflag=0
uflag=0
ask=0
INSTALL_DIR=""

# Options may be followed by one colon to indicate they have a required argument
# z and zulu are used for testing purposes only.
options=`getopt -q -o cdhruz -a --long compile,debug,help,required,uninstall,zulu -n $progname -- "$@"`

# Catches invalid options
if [ $? != 0 ]; then
    Warning "unrecognized option(s) ignored"
fi

# Processes valid options
eval set -- "$options"
while [ $# -gt 0 ]; do
    case $1 in
        -c | --compile)
            cflag=1
            ;;
        -d | --debug)
            dflag=1
            Debug "Turned ON."
            ;;
        -h | --help)
            Help
            Exit 0
            ;;
        -r | --required)
            rflag=1
            ;;
        -u | --uninstall)
            uflag=1
            ;;
        (--)
            shift
            break
            ;;
        (--*)
            # Catches long options that are allowed by getopt but not considered
            # in this case statement.
            Error "invalid long option $1"
            eflag=1
            ;;
        (-?)
            # Catches short options that are allowed by getopt but not considered
            # in this case statement.
            Error "invalid short option $1"
            eflag=1
            ;;
        (*)
            # Catches non-option arguments, to be processed later
            # (for the case when no -- was used to end option's section)
            break
            ;;
    esac
    shift
done

# Processes valid non-option arguments
shift $((OPTIND-1))
case $# in
    (0)
        INSTALL_DIR=$UNPACK_DIR
        ask=1
        ;;
    (*)
        INSTALL_DIR=$1
        GREP=`echo $INSTALL_DIR | grep "^/"`
        if [ $? -ne 0 ]; then
            INSTALL_DIR=${PWD}/${INSTALL_DIR}
        fi
        if [ ! -d $INSTALL_DIR ]; then
            mkdir -p $INSTALL_DIR 2>/dev/null
            if [ $? -ne 0 ]; then
                Tell "Cannot create this directory!"
                Tell "Please choose another one..."
                INSTALL_DIR=$UNPACK_DIR
                ask=1
            else
                Tell "Created directory $INSTALL_DIR\n"
            fi
        elif [ ! -w $INSTALL_DIR ]; then
            Tell "You do not appear to have write access to"
            Tell "$INSTALL_DIR."
            Tell "Please choose another directory for installation."
            INSTALL_DIR=$UNPACK_DIR
            ask=1
        fi
        shift
        ;;
esac

# Catches remaining non-option arguments
while [ $# -gt 0 ]; do
    case $1 in
        (*)
            Warning "invalid argument $1 ignored"
            ;;
    esac
    shift
done

if [ $eflag -eq 1 ]; then
    HelpAd
    Exit 1
fi
dflag=$(( dflag || debug ))
# Standard Prologue END

# Main Algorithm BEGIN
# Check working directory
if [ ! -f "$progname" ]; then
    Error   "Please run this script from inside the package directory."
    Explain "cd /some/path/$PACK_NAME/"
    Exit 1
fi

# Choice of installation directory
if [ $ask -eq 1 ]; then
    Doing "Choose Installation Directory:"
    Tell  "The default is the current directory."
fi
while [ $ask -eq 1 ]; do
    Tell "Please enter the installation directory now"
    read -p "     [$INSTALL_DIR]--> " answer
    test $answer
    if [ -z "$answer" ]; then
        ask=2
    else
        absolut=`echo $answer | grep "^/"`
        if [ $? -ne 0 ]; then
            answer=${PWD}/$answer
        fi
        if [ ! -d $answer ]; then
            read -p "     Do you want to create $answer ? [y]--> " makedir
            if [ -z "$makedir" ]; then
                makedir=y
            fi
            if [ $makedir = "y" ]; then
                mkdir -p $answer 2>/dev/null
                if [ $? -ne 0 ]; then
                    Tell "Cannot create this directory! Please choose another one...\n"
                else
                    INSTALL_DIR=$answer
                    ask=3
                    Tell "Created directory $INSTALL_DIR"
                fi
            fi
        elif [ ! -w $answer ]; then
            Tell "You do not appear to have write access to"
            Tell "$answer."
            Tell "Please choose another directory for installation."
        else
            INSTALL_DIR=$answer
            ask=4
            Tell "OK with $INSTALL_DIR"
        fi
    fi
done
if [ $ask -ne 0 ]; then
    Done "Choosing Installation Directory."
fi

if [ $uflag -eq 1 ]; then
    Doing "Un-Installing FIMS package from $INSTALL_DIR"
    if [ -d ${INSTALL_DIR}/${PACK_NAME} ]; then
        cd ${INSTALL_DIR}/${PACK_NAME}
    else
        Error   "package does not exist"
        Explain "${INSTALL_DIR}/${PACK_NAME} not found."
        Explain "First install the package with:"
        Explain "~$> fims_install.sh $INSTALL_DIR"
        Exit 1
    fi
    if [ -f ${PACK_NAME}.uninstall ]; then
        if [ $dflag -eq 1 ]; then
            cat ${PACK_NAME}.uninstall
        fi
        # Execute uninstaller macro
        chmod 755 ${PACK_NAME}.uninstall
        ./${PACK_NAME}.uninstall
        mv -f ${PACK_NAME}.uninstall ${PACK_NAME}.uninstall.done
        # Remove package directory
        cd ../.
        rm -rf ${INSTALL_DIR}/${PACK_NAME}
        # Remove package compressed files and installer
        # Leave only files distributed to users, if any
        if [ -f ${INSTALL_DIR}/${PACK_NAME}.tar.gz ]; then
            rm -f ${INSTALL_DIR}/${PACK_NAME}.tar.gz 2>&-
            rm -f ${INSTALL_DIR}/fims_install.sh 2>&-
        fi
        rm -f ${UNPACK_DIR}/${PACK_NAME}.tar.gz
    else
        Error   "package is just unpacked, not installed"
        Explain "${PACK_NAME}.uninstall not found in"
        Explain "${INSTALL_DIR}/${PACK_NAME}"
        Explain "First install the package with:"
        Explain "~$> fims_install.sh $INSTALL_DIR"
        Exit 1
    fi
    Done "Un-Installing FIMS package."
    Exit 0
fi

Banner "       ** Welcome to the FIMS installation script **"
Frame
Banner "PLEASE NOTE: This package is to be used for period $PERIOD"
Banner "             of observations for the ESO telescopes."
Banner "             Current date $datestamp belongs to period $period."
Banner "The Finding Chart plug-in included in this package may be"
Banner "used for any service mode program."
Banner "The FIMS tool in this package is specific to programs for"
Banner "$INSTRUMENT."
Frame

# Check package components
Doing "Checking package is present..."
if [ ! -f "${PACK_NAME}.tar.gz" ]; then
    Error   "Package ${PACK_NAME}.tar.gz not found"
    Explain "in $UNPACK_DIR"
    Explain "Make sure you have unpacked FIMS"
    Explain "distribution in that directory."
    Exit 1
else
    Tell "Package found here." 1
fi
Done "Checking package is present."

Doing "Checking PERL interpreter is available..."
PERL_EXEC=perl
$PERL_EXEC -v 2>&- > /dev/null
if [ $? -eq 0 ]; then
    PERL_PATH=`which $PERL_EXEC 2>/dev/null`
    Tell "Perl interpreter found in: "
    Tell "$PERL_PATH" 1
else
    Tell "Perl interpreter not found in your path."
    Tell "You can either decide to specify the path"
    Tell "to your Perl interpreter, or to use FIMS"
    Tell "without Perl (you won't be able to produce"
    Tell "Postscript files for MXU masks)"
    read -p "Would you like to specify the path for $PERL_EXEC ? [n] " answer
    if [ -z "$answer" ]; then
        Tell "FIMS will work without PERL."
    else
        Tell "Please enter the absolut path to $PERL_EXEC"
        answer=""
        default="/usr/bin/$PERL_EXEC"
        while [ -z "$answer" ]; do
            read -p "     [$default]:~> " answer
            absolut=`echo $answer | grep "^/"`
            if [ $? -ne 0 ]; then
                Tell "Please enter an absolute path starting with /"
                default=$answer
                answer=""
            fi
        done
        perlname=`echo $answer | awk '{i=split($1,a,"/"); if (i > 0) printf("%s",a[i]); else print("")}'`
        if [ "x$perlname" == "x$PERL_EXEC" ]; then
            $answer -v 2>&- > /dev/null
            perlname=""
        else
            $answer/$PERL_EXEC -v 2>&- > /dev/null
            perlname="/$PERL_EXEC"
        fi
        if [ $? -eq 0 ]; then
            PERL_PATH=$answer
            Tell "FIMS will use $answer$perlname"
        else
            Tell "It did not work. Sorry."
            Tell "Nevermind. FIMS will work without PERL."
        fi
    fi    
 
fi
Done  "Checking PERL interpreter is available."

Doing "Installing FIMS package in $INSTALL_DIR"

if [ -f "${UNPACK_DIR}/${PACK_NAME}.tar.gz" ]; then
    Doing "Unpacking ${UNPACK_DIR}/${PACK_NAME}.tar.gz" 1
    Tell  "to ${INSTALL_DIR}" 1
    rm -rf ${INSTALL_DIR}/${PACK_NAME} 2>&-
    rm -rf ${INSTALL_DIR}/${PACK_NAME}.uninstall.done 2>&-
    gzip -d -c ${UNPACK_DIR}/${PACK_NAME}.tar.gz | tar xvf - -C $INSTALL_DIR > /dev/null
    Done "Unpacking." 1
else
    Error   "Package ${PACK_NAME}.tar.gz not found"
    Explain "in $UNPACK_DIR"
    Exit 2
fi

# Create uninstaller macro
upath=${INSTALL_DIR}/${PACK_NAME}/${PACK_NAME}.uninstall
echo "# FIMS Un-Installer created ${datestamp}T${timestamp}" > $upath
echo "cd ${INSTALL_DIR}/${PACK_NAME}" >> $upath

# Compile FIMS tool
if [ $cflag -eq 1 ]; then
    Doing "Compiling FIMS Tool..." 1
    cd ${INSTALL_DIR}/${PACK_NAME}/src
    Doing "Unzipping source code..." 2
    gzip -d -c fims-*.tar.gz | tar xvf - -C . > /dev/null
    Done "Unzipping source code." 2
    Doing "Compiling fims module..." 2
    cd ./fims/src
    if [ -n "${VLTROOT}" ]; then
        # When building in a VLTSW environment,
        # the FIMS batch software is installed
        makefile=Makefile
        make -f $makefile all
    else
        makefile=makefile
        make -f $makefile all 2>&- > /dev/null
    fi
    # Copy binaries to bin
    for b in `ls -1AB --ignore='.svn' ../bin`; do
        rm -f ${INSTALL_DIR}/${PACK_NAME}/bin/$b
        cp -pf ../bin/$b ${INSTALL_DIR}/${PACK_NAME}/bin/$b
    done
    # Copy library to lib
    for l in libesoPlugins.tcl libfimsPlugins.tcl; do
        rm -rf ${INSTALL_DIR}/${PACK_NAME}/lib/$l
        cp -rp --remove-destination ../lib/$l ${INSTALL_DIR}/${PACK_NAME}/lib/.
    done
    # Copy configuration files to config
    for c in `ls -1AB --ignore='.svn' ../config`; do
        rm -f ${INSTALL_DIR}/${PACK_NAME}/config/$c
        cp -pf ../config/$c ${INSTALL_DIR}/${PACK_NAME}/config/.
    done
    # Clean up
    make -f $makefile -s clean 2>&- > /dev/null
    cd ../..
    Done "Compiling fims module." 2
    Done "Compiling FIMS Tool." 1
fi

Doing "Installing scripts, libraries and binaries..." 1
if [ -n "${VLTROOT}" ]; then
    vltroot=${VLTROOT}
else
    vltroot=${INSTALL_DIR}/${PACK_NAME}
fi
if [ -n "${INTROOT}" ]; then
    # If it is installed in a VLTSW directory structure, replace some libraries
    # and binaries in INTROOT. Tcl/Tk should be installed.
    if [ -d ${INTROOT}/bin ]; then
        binpath=${INTROOT}/bin
    fi
    if [ -d ${INTROOT}/lib ]; then
        libpath=${INTROOT}/lib
    fi
else
    # Create local links to libraries, executables and scripts
    if [ -z "$binpath" ]; then
        mkdir -p ${HOME}/binfims
        binpath=${HOME}/binfims
    fi
    if [ -z "$libpath" ]; then
        mkdir -p ${HOME}/libfims
        libpath=${HOME}/libfims
    fi
fi
cd ${INSTALL_DIR}/${PACK_NAME}
if [ -n "$binpath" ]; then
    Doing "Linking bin from $binpath..." 2
    for b in `ls -1AB ${PWD}/bin`; do
        SafeLink ${PWD}/bin/$b ${binpath}/$b
    done
    if [ $rflag -eq 1 ]; then
        Tell "Adding links to external pre-compiled binaries..." 2
        for eb in `ls -1AB ${PWD}/ext/bin`; do
            SafeLink ${PWD}/ext/bin/$eb ${binpath}/$eb
        done
    fi
    Done "Linking bin." 2
else
    Error   "could not define links to executables"
    Explain "Cannot complete install."
    Exit 2
fi
    
if [ -n "$libpath" ]; then
    Doing "Linking lib from $libpath..." 2
    for l in `ls -1AB ${PWD}/lib`; do
        SafeLink ${PWD}/lib/$l ${libpath}/$l
    done
    if [ $rflag -eq 1 ]; then
        Tell "Adding links to external pre-compiled libraries..." 2
        for el in `ls -1AB ${PWD}/ext/lib`; do
            SafeLink ${PWD}/ext/lib/$el ${libpath}/$el
        done
    fi
    Done "Linking lib." 2
else
    Error   "could not define links to libraries"
    Explain "Cannot complete install."
    Exit 2
fi

mkdir -p ${HOME}/bin
SafeLink ${PWD}/bin/fims.sh ${HOME}/bin/fims.sh

# Add extra cleaning of bin and lib links to the uninstaller macro
if [ -n "$binpath" ]; then
    echo "rm -f \`ls -laAB $binpath 2>&- | grep $PACK_NAME | awk '{printf(\"$binpath/%s \",\$9)}'\`" >> $upath
fi
if [ -n "$libpath" ]; then
    echo "rm -f \`ls -laAB $libpath 2>&- | grep $PACK_NAME | awk '{printf(\"$libpath/%s \",\$9)}'\`" >> $upath
fi
Done "Installing scripts, libraries and binaries." 1

Doing "Updating PERL scripts..." 1
chmod u+w ${INSTALL_DIR}/${PACK_NAME}/bin/gerber2ps.perl
rm -f gerber2ps.perl.new
cat ${INSTALL_DIR}/${PACK_NAME}/bin/gerber2ps.perl | awk '{if(NR==1) printf("#!" A "\n"); else print $0}' A=$PERL_PATH > gerber2ps.perl.new
mv -f gerber2ps.perl.new ${INSTALL_DIR}/${PACK_NAME}/bin/gerber2ps.perl

chmod u+w ${INSTALL_DIR}/${PACK_NAME}/bin/gerber2eps.perl
rm -f gerber2eps.perl.new
cat ${INSTALL_DIR}/${PACK_NAME}/bin/gerber2eps.perl | awk '{if(NR==1) printf("#!" A "\n"); else print $0}' A=$PERL_PATH > gerber2eps.perl.new
mv -f gerber2eps.perl.new ${INSTALL_DIR}/${PACK_NAME}/bin/gerber2eps.perl
chmod 555 ${INSTALL_DIR}/${PACK_NAME}/bin/*.perl
Done "Updating PERL scripts" 1

Doing "Updating launch script..." 1
# Jejeje, 27 backslashes to replace one / by \\\/ 
# (3 backslashes followed by a slash)
# giving a substitution like /my/full/path/to/fims/ for
# \\\/my\\\/full\\\/path\\\/to\\\/fims
# which is needed to pass this path string through sed again without the / being
# mistaken as pattern delimiters.
FIMS_PATH=`echo ${INSTALL_DIR}/${PACK_NAME} | sed s/[/]/\\\\\\\\\\\\\\\\\\\\\\\\\\\//g`
INS_PATH=`echo ${INSROOT} | sed s/[/]/\\\\\\\\\\\\\\\\\\\\\\\\\\\//g`
VLT_PATH=`echo ${vltroot} | sed s/[/]/\\\\\\\\\\\\\\\\\\\\\\\\\\\//g`
BIN_PATH=`echo ${binpath} | sed s/[/]/\\\\\\\\\\\\\\\\\\\\\\\\\\\//g`
LIB_PATH=`echo ${libpath} | sed s/[/]/\\\\\\\\\\\\\\\\\\\\\\\\\\\//g`
Debug "FIMS_ROOT   = >$FIMS_PATH<"
Debug "INSROOT     = >$INS_PATH<"
Debug "VLTROOT     = >$VLT_PATH<"
Debug "BINPATH     = >$BIN_PATH<"
Debug "LIBPATH     = >$LIB_PATH<"
Debug "INSUSER     = >$INSUSER<"
sed -e s/@@FIMSBASEPATH@@/$FIMS_PATH/ \
    -e s/@@INSPATH@@/$INS_PATH/ \
    -e s/@@VLTPATH@@/$VLT_PATH/ \
    -e s/@@BINPATH@@/$BIN_PATH/ \
    -e s/@@LIBPATH@@/$LIB_PATH/ \
    -e s/@@USER@@/$INSUSER/ \
    ${INSTALL_DIR}/${PACK_NAME}/src/fims.sh.tpl > ${INSTALL_DIR}/${PACK_NAME}/bin/fims.sh

chmod 555 ${INSTALL_DIR}/${PACK_NAME}/bin/fims.sh
Done "Updating launch scripts." 1

Doing "Copying configuration files..." 1
# Create FIMS user directories
if [ ! -d "${INSROOT}/${INSUSER}" ]; then
    mkdir -p ${INSROOT}/${INSUSER}
fi
if [ ! -d "$PREP_DIR" ]; then
    mkdir -p $PREP_DIR
    chmod -f 666 $PREP_DIR/*
fi
if [ ! -d "$LOG_DIR" ]; then
    mkdir -p $LOG_DIR
    chmod -f 666 $LOG_DIR/*
fi
if [ ! -d "$SET_DIR" ]; then
    mkdir -p $SET_DIR
    chmod -f 666 $SET_DIR/*
fi

# Backup skycat.cfg
if [ -f "${INSROOT}/${INSUSER}/skycat.cfg" ]; then
    mv -f ${INSROOT}/${INSUSER}/skycat.cfg ${INSROOT}/${INSUSER}/skycat.cfg.$datestamp.$timestamp
    echo "mv -f ${INSROOT}/${INSUSER}/skycat.cfg.$datestamp.$timestamp ${INSROOT}/${INSUSER}/skycat.cfg" >> $upath
fi
if [ -f "${INSROOT}/.skycat/skycat.cfg" ]; then
    mv -f ${INSROOT}/.skycat/skycat.cfg ${INSROOT}/.skycat/skycat.cfg.$datestamp.$timestamp
    echo "mv -f ${INSROOT}/.skycat/skycat.cfg.$datestamp.$timestamp ${INSROOT}/.skycat/skycat.cfg.orig" >> $upath
fi
# Copy configuration files
cp -pf ${INSTALL_DIR}/${PACK_NAME}/config/skycat.cfg ${INSROOT}/${INSUSER}/.
cp -pf ${INSTALL_DIR}/${PACK_NAME}/config/mxu2.???.standard.fad ${SET_DIR}/.
# Maybe some .fits, .cat, .fims for a beginners test
# can be copied to PREP_DIR, SET_DIR

Done "Copying configuration." 1
Done "Installing FIMS package."

Frame
Explain " "
Explain "Execute FIMS tool with:"
Explain "~$> ~/bin/fims.sh [B|R]"
Explain "     B: Configure for Blue CCD"
Explain "     R: Configure for Red CCD"
Explain "Have Fun With FIMS! "
Explain " "
Frame
# Main Algorithm END

# Standard Epilogue BEGIN
rm -f ${UNPACK_DIR}/${PACK_NAME}.tar.gz
Exit 0
# Standard Epilogue END

#
#___FIMS___
